# clams-utils

Repository that holds a collection of smaller helper/utility code of CLAMS platform.
Use PyPI release to install the package. 

``` bash 
pip install clams-utils
```

## Usage

Currently, this package provides utilities for speicific tasks related to the American Archive of Public Broadcasting (AAPB) project via `clams_utils.aapb` subpackage. All utilities are accessible via the command line interface (CLI) or can be imported as Python modules. See help messages for more details on included utilities.

``` bash
clams-aapb --help
```


